@@ -118,9 +118,13 @@ static gboolean is_authorized_for_domain (GDataAuthorizer *self, GDataAuthorizat
 static void notify_proxy_uri_cb (GObject *gobject, GParamSpec *pspec, GDataClientLoginAuthorizer *self);
 static void notify_timeout_cb (GObject *gobject, GParamSpec *pspec, GObject *self);
 
+static SoupURI *_get_proxy_uri (GDataClientLoginAuthorizer *self);
+static void _set_proxy_uri (GDataClientLoginAuthorizer *self, SoupURI *proxy_uri);
+
 struct _GDataClientLoginAuthorizerPrivate {
 	SoupSession *session;
 	SoupURI *proxy_uri; /* cached version only set if gdata_client_login_authorizer_get_proxy_uri() is called */
+	GProxyResolver *proxy_resolver;
 
 	gchar *client_id;
 
@@ -142,6 +146,7 @@ enum {
 	PROP_PASSWORD,
 	PROP_PROXY_URI,
 	PROP_TIMEOUT,
+	PROP_PROXY_RESOLVER,
 };
 
 enum {
@@ -227,6 +232,7 @@ gdata_client_login_authorizer_class_init (GDataClientLoginAuthorizerClass *klass
 	 * The proxy URI used internally for all network requests.
 	 *
 	 * Since: 0.9.0
+	 * Deprecated: Use #GDataClientLoginAuthorizer:proxy-resolver instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
 	 */
 	g_object_class_install_property (gobject_class, PROP_PROXY_URI,
 	                                 g_param_spec_boxed ("proxy-uri",
@@ -250,6 +256,19 @@ gdata_client_login_authorizer_class_init (GDataClientLoginAuthorizerClass *klass
 	                                                    0, G_MAXUINT, 0,
 	                                                    G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
+	/**
+	 * GDataClientLoginAuthorizer:proxy-resolver:
+	 *
+	 * The #GProxyResolver used to determine a proxy URI.  Setting this will clear the #GDataClientLoginAuthorizer:proxy-uri property.
+	 *
+	 * Since: 0.15.0
+	 */
+	g_object_class_install_property (gobject_class, PROP_PROXY_RESOLVER,
+	                                 g_param_spec_object ("proxy-resolver",
+	                                                      "Proxy Resolver", "A GProxyResolver used to determine a proxy URI.",
+	                                                      G_TYPE_PROXY_RESOLVER,
+	                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+
 	/**
 	 * GDataClientLoginAuthorizer::captcha-challenge:
 	 * @authorizer: the #GDataClientLoginAuthorizer which received the challenge
@@ -293,6 +312,9 @@ gdata_client_login_authorizer_init (GDataClientLoginAuthorizer *self)
 	/* Proxy the SoupSession's proxy-uri and timeout properties */
 	g_signal_connect (self->priv->session, "notify::proxy-uri", (GCallback) notify_proxy_uri_cb, self);
 	g_signal_connect (self->priv->session, "notify::timeout", (GCallback) notify_timeout_cb, self);
+
+	/* Keep our GProxyResolver synchronized with SoupSession's. */
+	g_object_bind_property (self->priv->session, "proxy-resolver", self, "proxy-resolver", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
 }
 
 static void
@@ -305,6 +327,8 @@ dispose (GObject *object)
 	}
 	priv->session = NULL;
 
+	g_clear_object (&priv->proxy_resolver);
+
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (gdata_client_login_authorizer_parent_class)->dispose (object);
 }
@@ -349,11 +373,14 @@ get_property (GObject *object, guint property_id, GValue *value, GParamSpec *psp
 			g_rec_mutex_unlock (&(priv->mutex));
 			break;
 		case PROP_PROXY_URI:
-			g_value_set_boxed (value, gdata_client_login_authorizer_get_proxy_uri (GDATA_CLIENT_LOGIN_AUTHORIZER (object)));
+			g_value_set_boxed (value, _get_proxy_uri (GDATA_CLIENT_LOGIN_AUTHORIZER (object)));
 			break;
 		case PROP_TIMEOUT:
 			g_value_set_uint (value, gdata_client_login_authorizer_get_timeout (GDATA_CLIENT_LOGIN_AUTHORIZER (object)));
 			break;
+		case PROP_PROXY_RESOLVER:
+			g_value_set_object (value, gdata_client_login_authorizer_get_proxy_resolver (GDATA_CLIENT_LOGIN_AUTHORIZER (object)));
+			break;
 		default:
 			/* We don't have any other property... */
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -371,11 +398,14 @@ set_property (GObject *object, guint property_id, const GValue *value, GParamSpe
 			priv->client_id = g_value_dup_string (value);
 			break;
 		case PROP_PROXY_URI:
-			gdata_client_login_authorizer_set_proxy_uri (GDATA_CLIENT_LOGIN_AUTHORIZER (object), g_value_get_boxed (value));
+			_set_proxy_uri (GDATA_CLIENT_LOGIN_AUTHORIZER (object), g_value_get_boxed (value));
 			break;
 		case PROP_TIMEOUT:
 			gdata_client_login_authorizer_set_timeout (GDATA_CLIENT_LOGIN_AUTHORIZER (object), g_value_get_uint (value));
 			break;
+		case PROP_PROXY_RESOLVER:
+			gdata_client_login_authorizer_set_proxy_resolver (GDATA_CLIENT_LOGIN_AUTHORIZER (object), g_value_get_object (value));
+			break;
 		default:
 			/* We don't have any other property... */
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -1093,18 +1123,9 @@ notify_proxy_uri_cb (GObject *object, GParamSpec *pspec, GDataClientLoginAuthori
 	g_object_notify (G_OBJECT (self), "proxy-uri");
 }
 
-/**
- * gdata_client_login_authorizer_get_proxy_uri:
- * @self: a #GDataClientLoginAuthorizer
- *
- * Gets the proxy URI on the #GDataClientLoginAuthorizer's #SoupSession.
- *
- * Return value: (transfer full): the proxy URI, or %NULL; free with soup_uri_free()
- *
- * Since: 0.9.0
- */
-SoupURI *
-gdata_client_login_authorizer_get_proxy_uri (GDataClientLoginAuthorizer *self)
+/* Static function which isn't deprecated so we can continue using it internally. */
+static SoupURI *
+_get_proxy_uri (GDataClientLoginAuthorizer *self)
 {
 	SoupURI *proxy_uri;
 
@@ -1123,6 +1144,34 @@ gdata_client_login_authorizer_get_proxy_uri (GDataClientLoginAuthorizer *self)
 	return proxy_uri;
 }
 
+/**
+ * gdata_client_login_authorizer_get_proxy_uri:
+ * @self: a #GDataClientLoginAuthorizer
+ *
+ * Gets the proxy URI on the #GDataClientLoginAuthorizer's #SoupSession.
+ *
+ * Return value: (transfer full): the proxy URI, or %NULL; free with soup_uri_free()
+ *
+ * Since: 0.9.0
+ * Deprecated: Use gdata_client_login_authorizer_get_proxy_resolver() instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
+ */
+SoupURI *
+gdata_client_login_authorizer_get_proxy_uri (GDataClientLoginAuthorizer *self)
+{
+	return _get_proxy_uri (self);
+}
+
+/* Static function which isn't deprecated so we can continue using it internally. */
+static void
+_set_proxy_uri (GDataClientLoginAuthorizer *self, SoupURI *proxy_uri)
+{
+	g_return_if_fail (GDATA_IS_CLIENT_LOGIN_AUTHORIZER (self));
+
+	g_object_set (self->priv->session, SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
+
+	/* Notification is handled in notify_proxy_uri_cb() which is called as a result of setting the property on the session */
+}
+
 /**
  * gdata_client_login_authorizer_set_proxy_uri:
  * @self: a #GDataClientLoginAuthorizer
@@ -1133,15 +1182,57 @@ gdata_client_login_authorizer_get_proxy_uri (GDataClientLoginAuthorizer *self)
  * If @proxy_uri is %NULL, no proxy will be used.
  *
  * Since: 0.9.0
+ * Deprecated: Use gdata_client_login_authorizer_set_proxy_resolver() instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
  */
 void
 gdata_client_login_authorizer_set_proxy_uri (GDataClientLoginAuthorizer *self, SoupURI *proxy_uri)
+{
+	_set_proxy_uri (self, proxy_uri);
+}
+
+/**
+ * gdata_client_login_authorizer_get_proxy_resolver:
+ * @self: a #GDataClientLoginAuthorizer
+ *
+ * Gets the #GProxyResolver on the #GDataClientLoginAuthorizer's #SoupSession.
+ *
+ * Return value: (transfer none) (allow-none): a #GProxyResolver, or %NULL
+ *
+ * Since: 0.15.0
+ */
+GProxyResolver *
+gdata_client_login_authorizer_get_proxy_resolver (GDataClientLoginAuthorizer *self)
+{
+	g_return_val_if_fail (GDATA_IS_CLIENT_LOGIN_AUTHORIZER (self), NULL);
+
+	return self->priv->proxy_resolver;
+}
+
+/**
+ * gdata_client_login_authorizer_set_proxy_resolver:
+ * @self: a #GDataClientLoginAuthorizer
+ * @proxy_resolver: (allow-none): a #GProxyResolver, or %NULL
+ *
+ * Sets the #GProxyResolver on the #SoupSession used internally by the given #GDataClientLoginAuthorizer.
+ *
+ * Setting this will clear the #GDataClientLoginAuthorizer:proxy-uri property.
+ *
+ * Since: 0.15.0
+ */
+void
+gdata_client_login_authorizer_set_proxy_resolver (GDataClientLoginAuthorizer *self, GProxyResolver *proxy_resolver)
 {
 	g_return_if_fail (GDATA_IS_CLIENT_LOGIN_AUTHORIZER (self));
+	g_return_if_fail (proxy_resolver == NULL || G_IS_PROXY_RESOLVER (proxy_resolver));
 
-	g_object_set (self->priv->session, SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
+	if (proxy_resolver != NULL) {
+		g_object_ref (proxy_resolver);
+	}
 
-	/* Notification is handled in notify_proxy_uri_cb() which is called as a result of setting the property on the session */
+	g_clear_object (&self->priv->proxy_resolver);
+	self->priv->proxy_resolver = proxy_resolver;
+
+	g_object_notify (G_OBJECT (self), "proxy-resolver");
 }
 
 static void
