@@ -882,11 +882,25 @@ gdata_entry_add_category (GDataEntry *self, GDataCategory *category)
 	/* Check to see if it's a kind category and if it matches the entry's predetermined kind */
 	if (g_strcmp0 (gdata_category_get_scheme (category), "http://schemas.google.com/g/2005#kind") == 0) {
 		GDataEntryClass *klass = GDATA_ENTRY_GET_CLASS (self);
+		GList *element;
 
 		if (klass->kind_term != NULL && g_strcmp0 (gdata_category_get_term (category), klass->kind_term) != 0) {
 			g_warning ("Adding a kind category term, '%s', to an entry of kind '%s'.",
 			           gdata_category_get_term (category), klass->kind_term);
 		}
+
+		/* If it is a kind category, remove the entry’s existing kind category to allow the new one
+		 * to be added. This is necessary because the existing category was set in
+		 * gdata_entry_constructed() and might not contain all the attributes of the actual XML
+		 * category.
+		 *
+		 * See: https://bugzilla.gnome.org/show_bug.cgi?id=707477 */
+		element = g_list_find_custom (self->priv->categories, category, (GCompareFunc) gdata_comparable_compare);
+		if (element != NULL) {
+			g_assert (GDATA_IS_CATEGORY (element->data));
+			g_object_unref (element->data);
+			self->priv->categories = g_list_delete_link (self->priv->categories, element);
+		}
 	}
 
 	/* Add the category if we don't already have it */
